﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

[CreateAssetMenu]
public class DancingAnimatorSO : ScriptableObject {

	// Here we create a hashset (a collection of unique items) of animators that we will use internally to trigger all animations.
	private HashSet<Animator> _animators = new HashSet<Animator>();

	// This will add an animator to the list of animators that we gonna control.
	public void RegisterAnimator(Animator animator) {
		_animators.Add(animator);
	}

	// This will remove an animator from our control.
	public void UnregisterAnimator(Animator animator) {
		_animators.Remove(animator);
	}

	// Just adding a bunch of methods to deal with the animation needs, you can add whatever you might need here!

	public void SetInteger(string paramName, int value) {
		foreach (Animator anim in _animators) {
			anim.SetInteger(paramName, value);
		}
	}

	public void SetBool(string paramName, bool value) {
		foreach (Animator anim in _animators) {
			anim.SetBool(paramName, value);
		}
	}

	public void SetFloat(string paramName, float value) {
		foreach (Animator anim in _animators) {
			anim.SetFloat(paramName, value);
		}
	}

	public void SetTrigger(string paramName) {
		foreach (Animator anim in _animators) {
			anim.SetTrigger(paramName);
		}
	}

	// Used to demo the system:
	public void ShowTime() {
		SetTrigger("Dance1");
		SetTrigger("Dance2");
		SetTrigger("Dance3");
	}
}
