﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayAnimComponent : MonoBehaviour {

	// Here we can have a reference set from the inspector to the ScriptableObject that is gonna sync all animations.
	public DancingAnimatorSO dancingAnimatorSO;

	// Having a reference to the animator to link it, also to control it individually if we need to.
	private Animator _animator;

	private void Awake() {
		_animator = GetComponent<Animator>();
	}

	// Here we give control of our animator, also we reset it so it can dance synced to the others.
	public void Register() {
		dancingAnimatorSO.RegisterAnimator(_animator);

		_animator.Play("Idle", -1, 0f);
		_animator.ResetTrigger("Dance1");
		_animator.ResetTrigger("Dance2");
		_animator.ResetTrigger("Dance3");
	}

	// Assuming direct control!
	public void Unregister() {
		dancingAnimatorSO.UnregisterAnimator(_animator);
	}

	// Common animator parameters setters
	public void SetInteger(string paramName, int value) {
		_animator.SetInteger(paramName, value);
	}

	public void SetBool(string paramName, bool value) {
		_animator.SetBool(paramName, value);
	}

	public void SetFloat(string paramName, float value) {
		_animator.SetFloat(paramName, value);
	}

	public void SetTrigger(string paramName) {
		_animator.SetTrigger(paramName);
	}
}
